# -------------------------------------------------------------------------------------------
#
# How to build for normal kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' madwifi.spec
#
# How to build for normal kernel and XEN kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildxen 1' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildxen 1' madwifi.spec
#
# How to build for normal kernel and PAE kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildPAE 1' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildPAE 1' madwifi.spec
#
# How to build for all kernel (normal, xen, PAE)
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-53.el5' --define 'buildall 1' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-53.el5' --define 'buildall 1' madwifi.spec
#
#
# How to build for the running kernel:
#
#  rpmbuild -ba --target i686   madwifi.spec
#  rpmbuild -ba --target x86_64 madwifi.spec
#
# -------------------------------------------------------------------------------------------

%{!?buildxen:%define buildxen 0}
%{!?buildPAE:%define buildPAE 0}

%{?buildall:%define buildxen 1}
%{?buildall:%define buildPAE 1}

%ifarch x86_64
%define buildPAE 0
%endif

%define pkg_name madwifi

%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path     %{_usrsrc}/kernels/%{kernel}-%{_target_cpu}
%define kernel_xen_src_path %{_usrsrc}/kernels/%{kernel}-xen-%{_target_cpu}
%define kernel_PAE_src_path %{_usrsrc}/kernels/%{kernel}-PAE-%{_target_cpu}

%define kernel_moduledir     /lib/modules/%{kernel}/kernel/drivers/net/wireless/%{pkg_name}
%define kernel_xen_moduledir /lib/modules/%{kernel}xen/kernel/drivers/net/wireless/%{pkg_name}
%define kernel_PAE_moduledir /lib/modules/%{kernel}PAE/kernel/drivers/net/wireless/%{pkg_name}

%define kmdl_name kernel-module-%{pkg_name}-%{kernel}
%define kmdl_name_hal kernel-module-%{pkg_name}-hal-%{kernel}

# -------------------------------------------------------------------------------------------

Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Name: 		%{pkg_name}
Version: 	0.9.3.3
Epoch:	        1
Release: 	12%{?dist}
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	proprietary
Group: 		System Environment/Kernel
URL: 		http://madwifi.org/
Source0: 	%{pkg_name}-%{version}.tar.gz
# Patch0: 	madwifi-2.6.18-autoconf.patch
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: 	sharutils
Requires:       kernel-module-%{pkg_name} >= %{epoch}:%{version}
BuildRequires:  kernel-devel = %{kernel}
%if %{buildxen}
BuildRequires:  kernel-xen-devel = %{kernel}
%endif
%if %{buildPAE}
BuildRequires:  kernel-PAE-devel = %{kernel}
%endif

%description
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

%package -n %{kmdl_name}
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal} = %{epoch}:%{version}

%description -n %{kmdl_name}
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.


%if %{buildxen}

%package -n %{kmdl_name}xen
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}xen = %{epoch}:%{version}

%description -n %{kmdl_name}xen
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%endif


%if %{buildPAE}

%package -n %{kmdl_name}PAE
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}PAE = %{epoch}:%{version}

%description -n %{kmdl_name}PAE
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%endif


%package -n %{kmdl_name_hal}
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name} = %{epoch}:%{version}

%description -n %{kmdl_name_hal}
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.


%if %{buildxen}

%package -n %{kmdl_name_hal}xen
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}xen = %{epoch}:%{version}

%description -n %{kmdl_name_hal}xen
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%if %{buildPAE}

%package -n %{kmdl_name_hal}PAE
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}PAE = %{epoch}:%{version}

%description -n %{kmdl_name_hal}PAE
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%prep
%setup -n %{pkg_name}-%{version}
# %patch0 -p1 -b .config

find . -name Makefile\* | xargs perl -pi -e's,/sbin/depmod,: /sbin/depmod,'

%build
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"

export TOOLPREFIX=`which gcc|sed -e's,gcc$,,'`
%ifarch %x86
export TARGET=i386-elf
%endif
%ifarch x86_64
export TARGET=x86_64-elf
%endif

# export COPTS="$COPTS -DNO_WME"

mkdir -p %{buildroot}%{_bindir}

### build tools
%{__make} clean
%{__make} -C tools \
     KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

%{__make} -C tools install DESTDIR=%{buildroot} \
     BINDIR=%{_bindir} MANDIR=%{_mandir} \
     KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

mv hal/COPYRIGHT hal/COPYRIGHT.hal
mv hal/README hal/README.hal


### UP kernel
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

export KERNELPATH=%{kernel_src_path}
export KERNELRELEASE=%{kernel}
mkdir -p %{buildroot}%{kernel_moduledir}
%{__make} KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel} \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_moduledir} \
     MODULEPATH=%{kernel_moduledir} \
     install-modules


%if %{buildxen}

### XEN kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_xen_src_path} \
     KERNELRELEASE=%{kernel}xen

export KERNELPATH=%{kernel_xen_src_path}
export KERNELRELEASE=%{kernel}xen
mkdir -p %{buildroot}%{kernel_xen_moduledir}
%{__make} KERNELPATH=%{kernel_xen_src_path} \
     KERNELRELEASE=%{kernel}xen \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_xen_moduledir} \
     MODULEPATH=%{kernel_xen_moduledir} \
     install-modules

%endif


%if %{buildPAE}

### PAE kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_PAE_src_path} \
     KERNELRELEASE=%{kernel}PAE

export KERNELPATH=%{kernel_PAE_src_path}
export KERNELRELEASE=%{kernel}PAE
mkdir -p %{buildroot}%{kernel_PAE_moduledir}
%{__make} KERNELPATH=%{kernel_PAE_src_path} \
     KERNELRELEASE=%{kernel}PAE \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_PAE_moduledir} \
     MODULEPATH=%{kernel_PAE_moduledir} \
     install-modules

%endif


%install

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}
depmod -a %{kernel} >/dev/null 2>&1 || :


%if %{buildxen}

%postun -n %{kmdl_name}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}xen
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%if %{buildPAE}

%postun -n %{kmdl_name}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}PAE
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%files 
%defattr(-,root,root,-)
%doc COPYRIGHT README hal/COPYRIGHT.hal hal/README.hal
%doc docs/users-guide.pdf docs/WEP-HOWTO.txt
%{_bindir}/athstats
%{_bindir}/80211stats
%{_bindir}/athdebug
%{_bindir}/80211debug
%{_bindir}/athchans
%{_bindir}/athctrl
%{_bindir}/athkey
%{_bindir}/wlanconfig
%{_mandir}/man8/80211debug.8*
%{_mandir}/man8/80211stats.8*
%{_mandir}/man8/athchans.8*
%{_mandir}/man8/athctrl.8*
%{_mandir}/man8/athdebug.8*
%{_mandir}/man8/athkey.8*
%{_mandir}/man8/athstats.8*
%{_mandir}/man8/wlanconfig.8*

%files -n %{kmdl_name}
%defattr(-,root,root,-)
%dir %{kernel_moduledir}
%{kernel_moduledir}/ath_pci.*o
%{kernel_moduledir}/ath_rate_*.*o
%{kernel_moduledir}/wlan.*o
%{kernel_moduledir}/wlan_acl.*o
%{kernel_moduledir}/wlan_ccmp.*o
%{kernel_moduledir}/wlan_tkip.*o
%{kernel_moduledir}/wlan_wep.*o
%{kernel_moduledir}/wlan_xauth.*o
%{kernel_moduledir}/wlan_scan_ap.*o
%{kernel_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}
%defattr(-,root,root,-)
%dir %{kernel_moduledir}
%{kernel_moduledir}/ath_hal.*o


%if %{buildxen}

%files -n %{kmdl_name}xen
%defattr(-,root,root,-)
%dir %{kernel_xen_moduledir}
%{kernel_xen_moduledir}/ath_pci.*o
%{kernel_xen_moduledir}/ath_rate_*.*o
%{kernel_xen_moduledir}/wlan.*o
%{kernel_xen_moduledir}/wlan_acl.*o
%{kernel_xen_moduledir}/wlan_ccmp.*o
%{kernel_xen_moduledir}/wlan_tkip.*o
%{kernel_xen_moduledir}/wlan_wep.*o
%{kernel_xen_moduledir}/wlan_xauth.*o
%{kernel_xen_moduledir}/wlan_scan_ap.*o
%{kernel_xen_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}xen
%defattr(-,root,root,-)
%dir %{kernel_xen_moduledir}
%{kernel_xen_moduledir}/ath_hal.*o

%endif


%if %{buildPAE}

%files -n %{kmdl_name}PAE
%defattr(-,root,root,-)
%dir %{kernel_PAE_moduledir}
%{kernel_PAE_moduledir}/ath_pci.*o
%{kernel_PAE_moduledir}/ath_rate_*.*o
%{kernel_PAE_moduledir}/wlan.*o
%{kernel_PAE_moduledir}/wlan_acl.*o
%{kernel_PAE_moduledir}/wlan_ccmp.*o
%{kernel_PAE_moduledir}/wlan_tkip.*o
%{kernel_PAE_moduledir}/wlan_wep.*o
%{kernel_PAE_moduledir}/wlan_xauth.*o
%{kernel_PAE_moduledir}/wlan_scan_ap.*o
%{kernel_PAE_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}PAE
%defattr(-,root,root,-)
%dir %{kernel_PAE_moduledir}
%{kernel_PAE_moduledir}/ath_hal.*o

%endif


%changelog
* Fri Nov 16 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.3.3-12
- add dist tag
- update to 0.9.3.3
- fix kernel_moduledir path

* Mon May 29 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.3.1-11.sl5
- do not build PAE kernel modules on x86_64
- update to 0.9.3.1

* Mon Apr 16 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.3-10.sl5
- madwifi-2.6.18-autoconf.patch no longer needed
- add modules matching ath_rate_*.*o
- update to 0.9.3

* Wed Mar 14 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.2.1-9.sl5.psi
- add xen PAE kernel packages
- add madwifi-2.6.18-autoconf.patch
- remove madwifi-0.9.2-rhel4.patch
- build for SL5

* Fri Dec 15 2006 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.2.1-8.sl4.psi
- add madwifi-0.9.2-rhel4.patch from ATrpms
- Introduce epoch since SL4 has 0.9.6 already. :/ 
- update to 0.9.2.1
- many changes in the spec file

* Thu Mar 02 2006 Urs Beyerle <urs.beyerle@psi.ch>
- build UP and SMP kernel modules

* Tue Feb 28 2006 Urs Beyerle <urs.beyerle@psi.ch>
- rebuild without ATrpms specific settings for SL4.

* Tue Feb 21 2006 Axel Thimm <Axel.Thimm@ATrpms.net>
- Split off non-GPL modules into their own subpackage
  to make GPL compliance unambiguous.

* Sat Feb 18 2006 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's svn.

* Sun Oct  2 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs (0.9.6.0).

* Thu Apr 14 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs.

* Sat Jan 22 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs.

* Tue Jan  4 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.4.12).

* Wed Dec 22 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs.

* Tue Nov  2 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.4.11).

* Wed Aug 18 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.3.1).

* Mon Jul 26 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to WPA cvs (0.9.2.2-WPA).

* Sun May 30 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.8.5.5).

* Wed Mar 24 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 0.8.5.4.

* Tue Feb  3 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Initial build.
